==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/LossSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LossSpecBuilder extends LossSpecFluentImpl<LossSpecBuilder> implements VisitableBuilder<LossSpec,LossSpecBuilder>{
  public LossSpecBuilder() {
    this(false);
  }
  public LossSpecBuilder(Boolean validationEnabled) {
    this(new LossSpec(), validationEnabled);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LossSpec(), validationEnabled);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent,LossSpec instance) {
    this(fluent, instance, false);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent,LossSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCorrelation(instance.getCorrelation());
      fluent.withLoss(instance.getLoss());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LossSpecBuilder(LossSpec instance) {
    this(instance,false);
  }
  public LossSpecBuilder(LossSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCorrelation(instance.getCorrelation());
      this.withLoss(instance.getLoss());
    }
    this.validationEnabled = validationEnabled; 
  }
  LossSpecFluent<?> fluent;
  Boolean validationEnabled;
  public LossSpec build() {
    LossSpec buildable = new LossSpec(fluent.getCorrelation(),fluent.getLoss());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/LossSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class LossSpecBuilder extends LossSpecFluent<LossSpecBuilder> implements VisitableBuilder<LossSpec,LossSpecBuilder>{
  public LossSpecBuilder() {
    this(false);
  }
  public LossSpecBuilder(Boolean validationEnabled) {
    this(new LossSpec(), validationEnabled);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new LossSpec(), validationEnabled);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent,LossSpec instance) {
    this(fluent, instance, false);
  }
  public LossSpecBuilder(LossSpecFluent<?> fluent,LossSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new LossSpec());

    if (instance != null) {
      fluent.withCorrelation(instance.getCorrelation());
      fluent.withLoss(instance.getLoss());
      fluent.withCorrelation(instance.getCorrelation());
      fluent.withLoss(instance.getLoss());
    }
    this.validationEnabled = validationEnabled; 
  }
  public LossSpecBuilder(LossSpec instance) {
    this(instance,false);
  }
  public LossSpecBuilder(LossSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new LossSpec());

    if (instance != null) {
      this.withCorrelation(instance.getCorrelation());
      this.withLoss(instance.getLoss());
      this.withCorrelation(instance.getCorrelation());
      this.withLoss(instance.getLoss());
    }
    this.validationEnabled = validationEnabled; 
  }
  LossSpecFluent<?> fluent;
  Boolean validationEnabled;
  public LossSpec build() {
    LossSpec buildable = new LossSpec(fluent.getCorrelation(),fluent.getLoss());
    return buildable;
  }
  
}
